/*
 *   Copyright (C) 2005 by Matthias Jauernig, Michael Lahl                 *
 *   rtc@linux-related.de, DJ-Mayday@web.de                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 */

package prog;

import java.awt.Graphics2D;

/**
 * 
 * @author Michael Lahl
 * @author Matthias Jauernig
 * 
 * Die Klasse Koch stellt den Algorithmus fr die Erstellung einer Kochkurve
 * in der Methode <code>zeichnen()</code> zur Verfgung. Sie erweiter damit die Klasse
 * ZPanel, auf der mit der Methode <code>zeichnen()</code> eine Kochkurve gezeichnet
 * werden kann.
 *
 * $Id: Koch.java,v 1.4 2005/06/21 07:41:52 mlahl Exp $
 */

public class Koch extends ZPanel{
	private static final long serialVersionUID = 1L;

	/**
	 * Methode implementiert den Algorithmus fr das zeichnen einer Kochkurve.
	 * Zum zeichnen einer Kurve wird die Methode rekursiv aufgerufen bis zu einer
	 * eingegebenen Ordnung.
	 * 
	 * @param g2D bergebenes ZPanel auf dem die Kurve gezeichnet werden soll
	 * @param ord zum Inkrementieren der gerade bearbeiteten Ordnung
	 * @param n maximal zu zeichnende Ordnung (Grenzordnung)
	 * @param x1 x Koordinate des Anfangspunktes
	 * @param y1 y Koordinate des Anfangspunktes
	 * @param x2 x Koordinate des Endpunktes
	 * @param y2 y Koordinate des Endpunktes
	 */
	public void zeichnen(Graphics2D g2D, int ord, int n, int x1, int y1, int x2, int y2){
		//Variablen fr die Punkte, die enstehen bei der Teilung der Geraden
		//in 3 gleich groe Teile
		int x3=0 , y3=0 , x4=0, y4=0, x5=0, y5=0, l;
		double dx, dy, f;

		dx = x2-x1; dy = y2-y1;
		l = (int)Math.round(Math.sqrt(dx*dx+dy*dy));
		if((ord >= n)||(l == 0)){
			//Linie zeichenen wenn eingegebene Ordnung erreicht
			g2D.drawLine(x1, y1, x2, y2);
			return;
		}else{
			x3 = x1+(x2-x1)/3; x4 = x2-(x2-x1)/3;
			y3 = y1+(y2-y1)/3; y4 = y2-(y2-y1)/3;
			f = 0.2886751333;
			x5 = (int)Math.round(x1+dx/2-f*dy);
			y5 = (int)Math.round(y1+dy/2+f*dx);
		}
		//Rekursiver Aufruf fr jede der entstandenen Linien
		zeichnen(g2D, ord+1, n, x1, y1, x3, y3);
		zeichnen(g2D, ord+1, n, x3, y3, x5, y5);
		zeichnen(g2D, ord+1, n, x5, y5, x4, y4);
		zeichnen(g2D, ord+1, n, x4, y4, x2, y2);
	}
}
