/*
 *   Peano.java		30.5.05
 * 
 *   Copyright (C) 2005 by Matthias Jauernig, Michael Lahl                 *
 *   rtc@linux-related.de, DJ-Mayday@web.de                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 */

package prog;

import java.awt.Graphics2D;

/**
 * 
 * @author Michael Lahl
 * @author Matthias Jauernig
 * 
 * Die Klasse Peano stellt den Algorithmus fr die Erstellung einer Peanokurve
 * in der Methode <code>zeichnen()</code> zur Verfgung. Sie erweiter damit die Klasse
 * ZPanel, auf der mit der Methode <code>zeichnen()</code> eine Peanokurve gezeichnet
 * werden kann.
 * 
 * @param <code>public static boolean[] visible</code> : dieses Array enthlt die zu zeichnenden Peano-Kanten
 */

public class Peano extends ZPanel{

	private static final long serialVersionUID = 1L;
	//Array fr die zu zeichnenden Kanten
	public static boolean[] visible = {false,false,false,false,false,false,false,false,false};
	
	/**
	 * Methode implementiert den Algorithmus fr das zeichnen einer Peanokurve.
	 * Zum zeichnen einer Kurve wird die Methode rekursiv aufgerufen bis zu einer
	 * eingegebenen Ordnung.
	 * 
	 * @param g2D bergebenes ZPanel auf dem die Kurve gezeichnet werden soll
	 * @param ord zum Inkrementieren der gerade bearbeiteten Ordnung
	 * @param n maximal zu zeichnende Ordnung (Grenzordnung)
	 * @param x1 x Koordinate des Anfangspunktes
	 * @param y1 y Koordinate des Anfangspunktes
	 * @param dx x Lnge der Kurve
	 * @param dy y Lnge der Kurve
	 */
	public void zeichnen(Graphics2D g2D, int ord, int n, int x1, int y1, int dx, int dy){
		//Zeichnen der Linie wenn die Grenzordnung erreicht wurde
		if((ord >= n)){
			g2D.drawLine(x1, y1, x1+dx, y1+dy);
			return;
		}else{
			//Wenn die Grenzordnung noch nicht erreicht ist dann werden neue
			//Werte berechnet und eine nchste Rekursion aufgerufen
			dx = dx/3; dy = dy/3;
			if(visible[0])
				zeichnen(g2D, ord+1, n, x1, y1, dx, dy);
				x1 = x1+dx; y1 = y1+dy;
			
			if(visible[3])
				zeichnen(g2D, ord+1, n, x1, y1, -dy, dx);
				x1 = x1-dy; y1 = y1+dx;
			
			if(visible[4])
				zeichnen(g2D, ord+1, n, x1, y1, dx, dy);
				x1 = x1+dx; y1 = y1+dy;
			
			if(visible[5])
				zeichnen(g2D, ord+1, n, x1, y1, dy, -dx);
				x1 = x1+dy; y1 = y1-dx;
			
			if(visible[1])
				zeichnen(g2D, ord+1, n, x1, y1, -dx, -dy);
				x1 = x1-dx; y1 = y1-dy;
			
			if(visible[6])
				zeichnen(g2D, ord+1, n, x1, y1, dy, -dx);
				x1 = x1+dy; y1 = y1-dx;
			
			if(visible[7])
				zeichnen(g2D, ord+1, n, x1, y1, dx, dy);
				x1 = x1+dx; y1 = y1+dy;
			
			if(visible[8])
				zeichnen(g2D, ord+1, n, x1, y1, -dy, dx);
				x1 = x1-dy; y1 = y1+dx;
			
			if(visible[2])
				zeichnen(g2D, ord+1, n, x1, y1, dx, dy);		
		}
	}
}
