/*
 *   Copyright (C) 2005 by Matthias Jauernig, Michael Lahl                 *
 *   rtc@linux-related.de, DJ-Mayday@web.de                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 */

package prog;

import java.awt.Graphics2D;
import java.awt.Color;

/**
 * 
 * @author Michael Lahl
 * @author Matthias Jauernig
 * 
 * Die Klasse Star stellt den Algorithmus fr die Erstellung eines Stern-Fraktals
 * in der Methode <code>zeichnen()</code> zur Verfgung. Sie erweiter damit die Klasse
 * ZPanel, auf der mit der Methode <code>zeichnen()</code> ein Stern-Fraktal gezeichnet
 * werden kann.
 *
 * $Id: Star.java,v 1.1 2005/06/21 08:51:21 mjauerni Exp $
 */

public class Star extends ZPanel{
	private static final long serialVersionUID = 1L;

	/**
	 * Methode implementiert den Algorithmus fr das zeichnen einer Kochkurve.
	 * Zum zeichnen einer Kurve wird die Methode rekursiv aufgerufen bis zu einer
	 * eingegebenen Ordnung.
	 * 
	 * @param g2D bergebenes ZPanel auf dem die Kurve gezeichnet werden soll
	 * @param ord zum Inkrementieren der gerade bearbeiteten Ordnung
	 * @param n maximal zu zeichnende Ordnung (Grenzordnung)
	 * @param x1 x Koordinate des Anfangspunktes
	 * @param y1 y Koordinate des Anfangspunktes
	 * @param x2 x Koordinate des Endpunktes
	 * @param y2 y Koordinate des Endpunktes
	 */
	public void zeichnen(Graphics2D g2D, int n, int x, int y, int r){
		if(n>=0 && r>1){
			/* zeichne Rechtecke mit halbem Radius an jede Ecke des akt. Rechtecks*/
			zeichnen(g2D, n-1, x-r, y-r, Math.round(r/2));
			zeichnen(g2D, n-1, x-r, y+r, Math.round(r/2));
			zeichnen(g2D, n-1, x+r, y-r, Math.round(r/2));
			zeichnen(g2D, n-1, x+r, y+r, Math.round(r/2));
			/* zeichne das Rechteck */
			g2D.setColor(Color.blue);
			g2D.fillRect(x-r, y-r, 2*r, 2*r);
		}
	}
}

